@@ -29,6 +29,7 @@ from psutil import POSIX
 from psutil import SUNOS
 from psutil import WINDOWS
 from psutil._compat import long
+from psutil._compat import unicode
 from psutil.tests import AF_INET6
 from psutil.tests import APPVEYOR
 from psutil.tests import check_net_address
@@ -111,7 +112,7 @@ class TestSystemAPIs(unittest.TestCase):
         gone, alive = test(procs, callback)
         self.assertIn(sproc3.pid, [x.pid for x in gone])
         if POSIX:
-            self.assertEqual(gone.pop().returncode, signal.SIGTERM)
+            self.assertEqual(gone.pop().returncode, -signal.SIGTERM)
         else:
             self.assertEqual(gone.pop().returncode, 1)
         self.assertEqual(l, [sproc3.pid])
@@ -453,6 +454,10 @@ class TestSystemAPIs(unittest.TestCase):
         # AssertionError: Lists differ: [0, 1, 2, 3, 4, 5, 6, 7,... != [0]
         self.assertTrue(ls, msg=ls)
         for disk in ls:
+            self.assertIsInstance(disk.device, (str, unicode))
+            self.assertIsInstance(disk.mountpoint, (str, unicode))
+            self.assertIsInstance(disk.fstype, (str, unicode))
+            self.assertIsInstance(disk.opts, (str, unicode))
             if WINDOWS and 'cdrom' in disk.opts:
                 continue
             if not POSIX:
@@ -467,7 +472,6 @@ class TestSystemAPIs(unittest.TestCase):
             else:
                 assert os.path.isdir(disk.mountpoint), disk
             assert disk.fstype, disk
-            self.assertIsInstance(disk.opts, str)
 
         # all = True
         ls = psutil.disk_partitions(all=True)
@@ -511,6 +515,7 @@ class TestSystemAPIs(unittest.TestCase):
                 self.assertIn(conn.family, families, msg=conn)
                 if conn.family != getattr(socket, 'AF_UNIX', object()):
                     self.assertIn(conn.type, types_, msg=conn)
+                self.assertIsInstance(conn.status, (str, unicode))
 
         from psutil._common import conn_tmap
         for kind, groups in conn_tmap.items():
@@ -546,6 +551,7 @@ class TestSystemAPIs(unittest.TestCase):
         self.assertNotEqual(ret, [])
         for key in ret:
             self.assertTrue(key)
+            self.assertIsInstance(key, (str, unicode))
             check_ntuple(ret[key])
 
     def test_net_if_addrs(self):
@@ -561,6 +567,7 @@ class TestSystemAPIs(unittest.TestCase):
 
         families = set([socket.AF_INET, AF_INET6, psutil.AF_LINK])
         for nic, addrs in nics.items():
+            self.assertIsInstance(nic, (str, unicode))
             self.assertEqual(len(set(addrs)), len(addrs))
             for addr in addrs:
                 self.assertIsInstance(addr.family, int)
@@ -683,6 +690,9 @@ class TestSystemAPIs(unittest.TestCase):
         self.assertNotEqual(users, [])
         for user in users:
             assert user.name, user
+            self.assertIsInstance(user.name, (str, unicode))
+            self.assertIsInstance(user.terminal, (str, unicode, None))
+            self.assertIsInstance(user.host, (str, unicode, None))
             user.terminal
             user.host
             assert user.started > 0.0, user
@@ -697,6 +707,27 @@ class TestSystemAPIs(unittest.TestCase):
             if name in ('ctx_switches', 'interrupts'):
                 self.assertGreater(value, 0)
 
+    @unittest.skipUnless(hasattr(psutil, "cpu_freq"),
+                         "platform not suported")
+    def test_cpu_freq(self):
+        def check_ls(ls):
+            for nt in ls:
+                self.assertLessEqual(nt.current, nt.max)
+                for name in nt._fields:
+                    value = getattr(nt, name)
+                    self.assertIsInstance(value, (int, long, float))
+                    self.assertGreaterEqual(value, 0)
+
+        ls = psutil.cpu_freq(percpu=True)
+        if TRAVIS and not ls:
+            return
+
+        assert ls, ls
+        check_ls([psutil.cpu_freq(percpu=False)])
+
+        if LINUX:
+            self.assertEqual(len(ls), psutil.cpu_count())
+
     def test_os_constants(self):
         names = ["POSIX", "WINDOWS", "LINUX", "OSX", "FREEBSD", "OPENBSD",
                  "NETBSD", "BSD", "SUNOS"]
@@ -734,6 +765,37 @@ class TestSystemAPIs(unittest.TestCase):
         for name in names:
             self.assertIs(getattr(psutil, name), False, msg=name)
 
+    @unittest.skipUnless(hasattr(psutil, "sensors_temperatures"),
+                         "platform not suported")
+    def test_sensors_temperatures(self):
+        temps = psutil.sensors_temperatures()
+        for name, entries in temps.items():
+            self.assertIsInstance(name, (str, unicode))
+            for entry in entries:
+                self.assertIsInstance(entry.label, (str, unicode))
+                if entry.current is not None:
+                    self.assertGreaterEqual(entry.current, 0)
+                if entry.high is not None:
+                    self.assertGreaterEqual(entry.high, 0)
+                if entry.critical is not None:
+                    self.assertGreaterEqual(entry.critical, 0)
+
+    @unittest.skipUnless(LINUX or WINDOWS or FREEBSD,
+                         "platform not supported")
+    def test_sensors_battery(self):
+        ret = psutil.sensors_battery()
+        if ret is None:
+            return  # no battery
+        self.assertGreaterEqual(ret.percent, 0)
+        self.assertLessEqual(ret.percent, 100)
+        if ret.secsleft not in (psutil.POWER_TIME_UNKNOWN,
+                                psutil.POWER_TIME_UNLIMITED):
+            self.assertGreaterEqual(ret.secsleft, 0)
+        else:
+            if ret.secsleft == psutil.POWER_TIME_UNLIMITED:
+                self.assertTrue(ret.power_plugged)
+        self.assertIsInstance(ret.power_plugged, bool)
+
 
 if __name__ == '__main__':
     run_test_module_by_name(__file__)
